#[non_exhaustive]pub enum ClientBuildError {
DatabaseNotInitialized,
DatabaseAlreadyInitialized,
SecretMismatch,
ConfigDownload(Box<ClientConfigDownloadError>),
ConfigDecode(DecodeError),
Migration(DbMigrationError),
ModuleRecoveryPrepare {
kind: ModuleKind,
instance_id: ModuleInstanceId,
source: Box<dyn Error + Send + Sync>,
},
ModuleInit {
kind: ModuleKind,
instance_id: ModuleInstanceId,
source: Box<dyn Error + Send + Sync>,
},
Database(DatabaseError),
AlreadyStopped,
}Expand description
A failure to open, join or recover a client.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
DatabaseNotInitialized
The database was never joined to a federation.
DatabaseAlreadyInitialized
The database already belongs to a federation and cannot be joined again.
SecretMismatch
The secret does not match the one the database was created with.
ConfigDownload(Box<ClientConfigDownloadError>)
The federation’s client config could not be downloaded.
ConfigDecode(DecodeError)
The stored client config could not be decoded with the modules this client was built with.
Migration(DbMigrationError)
A database migration failed.
ModuleRecoveryPrepare
A module could not prepare its recovery.
Fields
kind: ModuleKindThe kind of the module that failed.
instance_id: ModuleInstanceIdThe instance of the module that failed.
ModuleInit
A module could not be initialized.
Fields
kind: ModuleKindThe kind of the module that failed.
instance_id: ModuleInstanceIdThe instance of the module that failed.
Database(DatabaseError)
The database write failed.
AlreadyStopped
The client handle was already shut down and cannot be restarted.